@@ -22,7 +22,7 @@ from astersay.backends.yandex.proto.stt_service_pb2_grpc import SttServiceStub
 class YandexRecognizer(YandexBaseBackend):
     pause = True
     HOST = 'stt.api.cloud.yandex.net:443'
-    LANGUAGE_CODES = ('ru-RU', 'en-US', 'tr-TR')
+    LANGUAGES = ('ru-RU', 'en-US', 'tr-TR')
     MODELS = {
         'ru-RU': ('general', 'general:rc'),
         'tr-TR': ('general', 'maps'),
@@ -42,12 +42,12 @@ class YandexRecognizer(YandexBaseBackend):
 
         recognizer = conf['recognizer']
 
-        language_code = recognizer['language_code']
-        assert language_code in self.LANGUAGE_CODES
-        self.language_code = language_code
+        language = recognizer['language_code']
+        assert language in self.LANGUAGES
+        self.language = language
 
         model = recognizer['model']
-        assert model in self.MODELS[language_code]
+        assert model in self.MODELS[language]
         self.model = model
 
         self.profanity_filter = bool(recognizer['profanity_filter'])
@@ -75,7 +75,7 @@ class YandexRecognizer(YandexBaseBackend):
 
         # Задаём настройки распознавания.
         specification = RecognitionSpec(
-            language_code=self.language_code,
+            language_code=self.language,
             model=self.model,
             profanity_filter=self.profanity_filter,
             partial_results=self.partial_results,
@@ -98,8 +98,7 @@ class YandexRecognizer(YandexBaseBackend):
         # Установить соединение с сервером.
         channel = grpc.secure_channel(self.HOST, self._credentials)
         stub = SttServiceStub(channel)
-        iam_token = str(self.token_manager.token)
-        metadata = (('authorization', 'Bearer %s' % iam_token),)
+        metadata = self.token_manager.get_metadata()
         iter = stub.StreamingRecognize(get_request_iter(), metadata=metadata)
         try:
             for value in iter:
