@@ -5,13 +5,15 @@
 #
 import json
 import re
+import requests
 import sys
 from datetime import datetime
 from gettext import gettext as _
 from logging import getLogger
 from logging.config import dictConfig
-from os import makedirs
-from os.path import join as path_join, expanduser, abspath, exists, dirname
+from os import makedirs, remove
+from os.path import join as path_join, expanduser, abspath, exists, dirname, basename
+from threading import Thread
 
 from astersay.utils import prepare_dialog_name, import_string
 
@@ -298,6 +300,14 @@ def get_main_config(work_dir):
         'synthesizer': 'astersay.backends.yandex.YandexSynthesizer',
         'morphology_processor': 'astersay.morphology.Pymorphy2Processor',
         'export': '{work_dir}/export/{date}/{dialog}_{time}.json',
+        'remote_export': {
+            'active': False,
+            'url': 'https://example.com',
+            'headers': {},
+            'mode': 'data',  # 'data' для отправки json, 'file' для отправка файла
+            'delete_local_on_success': True,  # удалить локальный файл в случае успеха
+            'retries_on_failure': 3,  # кол-во попыток в случае неудачи
+        },
         'disable_stop_voices': False,
     }
     return get_config(work_dir, default, 'main')
@@ -469,6 +479,21 @@ def get_tinkoff_config(work_dir):
     return get_config(work_dir, default, 'tinkoff')
 
 
+def make_export_data(agi_params_data: dict, export_data: dict,
+                     text_buffers: dict, **extra):
+    data = {
+        'agi': agi_params_data,
+        'export': export_data,
+        'speech': text_buffers,
+    }
+    if extra:
+        assert 'agi' not in extra
+        assert 'export' not in extra
+        assert 'speech' not in extra
+        data.update(extra)
+    return data
+
+
 class Settings:
     """
     Конструктор для объекта управления настройками запускаемого приложения.
@@ -595,20 +620,54 @@ class Settings:
         }
         filename = export.format(**kw)
         makedirs(dirname(filename), 0o700, exist_ok=True)
-        data = {
-            'agi': agi_params_data,
-            'export': export_data,
-            'speech': text_buffers,
-        }
-        if extra:
-            assert 'agi' not in extra
-            assert 'export' not in extra
-            assert 'speech' not in extra
-            data.update(extra)
+        data = make_export_data(agi_params_data, export_data, text_buffers, **extra)
         json.dump(data, open(filename, 'w'),
                   indent=4, ensure_ascii=False)
+        export_thread = Thread(target=self.remote_export_dialog,
+                               args=(filename, data))
+        export_thread.start()
+
         return filename
 
+    def remote_export_dialog(self, filename, data=None):
+        export = self.main.get('remote_export')
+        if not export.get('active'):
+            return
+        assert export['mode'] in ('file', 'data')
+        assert export['retries_on_failure'] > 0
+
+        logger_info = logger.info
+        logger_error = logger.error
+        request_url = export['url']
+        request_args = {'headers': export['headers']}
+
+        if export['mode'] == 'file':
+            request_args['files'] = {filename: open(filename, 'rb')}
+            request_args['data'] = {'filename': basename(filename)}
+        if export['mode'] == 'data':
+            if not data:
+                data = json.load(open(filename))
+            request_args['data'] = data
+            request_args['params'] = {'filename': basename(filename)}
+
+        for n in [export['retries_on_failure']]:
+            try:
+                res = requests.post(request_url, timeout=(2, 5), **request_args)
+                if res.status_code == 200:
+                    logger_info(_('Диалог экспортирован на удаленный сервер %(url)s в режиме %(mode)s'),
+                                {'url': request_url, 'mode': export['mode']})
+                    if export['delete_local_on_success'] and filename:
+                        try:
+                            remove(filename)
+                            logger_info(_('Локальный файл диалога %s удален'), filename)
+                        except FileNotFoundError:
+                            logger_error(_('Локальный файл диалога %s не найден.'), filename)
+                    break
+            except requests.exceptions.Timeout:
+                logger_error(_('Timeout при экспорте диалога на удаленный сервер.'))
+            except requests.exceptions.RequestException as e:
+                logger_error(_('Ошибка при экспорте диалога на удаленный сервер: %s'), e.strerror, exc_info=e)
+
     def get_stop_file(self):
         if self.main.get('disable_stop_voices'):
             logger.info(_('Остановка голоса отключена в настройках.'))
