@@ -132,10 +132,10 @@ def prepare_answer(answer, export_name, script, variables, source=None):
             variables[export_name + '_label'] = labels[answer]
         names = convert.get('names')
         if names and answer in names:
-            variables[export_name + '_name'] = labels[answer]
+            variables[export_name + '_name'] = names[answer]
         texts = convert.get('texts')
         if texts and answer in texts:
-            variables[export_name + '_text'] = labels[answer]
+            variables[export_name + '_text'] = texts[answer]
     # Устанавливаем изменённый текст ответа в главную переменную.
     variables[export_name] = answer
 
@@ -559,7 +559,7 @@ class BaseDialog:
 
         log_info(_('Диалог завершён.'))
 
-    def execute_plugin(self, name, result, speech, variables):
+    def execute_plugin(self, name, result, speech, variables, config=None):
         """
         Возвращает кортеж из результата выполнения подпроцесса и словаря данных,
         которыми плагин оперировал.
@@ -575,6 +575,7 @@ class BaseDialog:
             'variables': variables,
             'chain': self.chain,
             'text_buffers': self.text_buffers,
+            'config': config
         }
         if result is None or \
                 isinstance(result, (str, bool, list, tuple, int, float)):
@@ -611,6 +612,7 @@ class BaseDialog:
                     for txt in synthesize:
                         self.synthesizer.make_voice(str(txt), early=True)
                     log_debug(_('Предварительный синтез речи завершён.'))
+
                 t = Thread(target=make_voices, daemon=True)
                 t.start()
             # Логгирование каких-либо строк из плагина.
@@ -659,7 +661,14 @@ class BaseDialog:
             scrypt_type = script['type']
             # Здесь должна возникать ошибка AttributeError для сломанных схем.
             method = getattr(self, '_script_%s' % scrypt_type)
-            log_debug('  SCRIPT %s', name.upper())
+
+            debug_msg = '  SCRIPT %s'
+            debug_args = [name.upper()]
+            if 'group' in process:
+                debug_msg += ' GROUP %s'
+                debug_args.append(process['group'].upper())
+            log_debug(debug_msg, *debug_args)
+
             self.partials_begin = 0
             if 'partials_begin' in script:
                 try:
@@ -684,7 +693,8 @@ class BaseDialog:
             # Запускаем плагин при его наличии.
             plugin_name = process.get('plugin')
             if plugin_name:
-                self.execute_plugin(plugin_name, result, speech, variables)
+                plugin_conf = process.get('plugin_conf')
+                self.execute_plugin(plugin_name, result, speech, variables, plugin_conf)
 
             # Устанавливаем следующий процесс.
             success = process.get('success')
@@ -1295,8 +1305,9 @@ class BaseDialog:
         result = True
         plugin_name = script.get('plugin_before')
         if plugin_name:
+            plugin_conf = script.get('plugin_before_conf')
             res, plugin_data = self.execute_plugin(
-                plugin_name, result, '', variables)
+                plugin_name, result, '', variables, plugin_conf)
             result = plugin_data.get('result')
 
         saydata = script.get('say_start')
@@ -1309,8 +1320,9 @@ class BaseDialog:
 
         plugin_name = script.get('plugin_after')
         if plugin_name:
+            plugin_conf = script.get('plugin_after_conf')
             res, plugin_data = self.execute_plugin(
-                plugin_name, result, '', variables)
+                plugin_name, result, '', variables, plugin_conf)
             result = plugin_data.get('result')
 
         if result:
