@@ -18,12 +18,18 @@ def words_iterator(text):
 class Pymorphy2Processor:
     parse = pymorphy2.MorphAnalyzer().parse
 
+    # Имена, которые не определяет pymorphy2.
+    extra_names = (
+        'Роман',
+    )
+
     def parse_names(self, text):
         """Метод ищет в тексте все имена."""
         parse = self.parse
         # probability score threshold
         prob_thresh = 0.4
         L = []
+        extra = self.extra_names
         for word in words_iterator(text):
             for p in parse(word):
                 if 'Name' in p.tag and p.score >= prob_thresh:
@@ -32,4 +38,7 @@ class Pymorphy2Processor:
                 elif 'Patr' in p.tag and p.score >= prob_thresh:
                     L.append(word.title())
                     break
+                elif word in extra:
+                    L.append(word.title())
+                    break
         return L
